<?php
/**
 * angularity Theme Customizer
 *
 * @package angularity
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function angularity_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

// Add Sections

$wp_customize->add_section('fonts' , array(
    'title' => __('Fonts','angularity'),
));

$wp_customize->add_section('angles' , array(
    'title' => __('Angularity','angularity'),
));

$wp_customize->add_section('image_options' , array(
    'title' => __('Image Options','angularity'),
));

$wp_customize->add_section('site_title' , array(
    'title' => __('Site Title','angularity'),
));


//Colors

$colors = array();

$colors[] = array(
	'slug'=>'site_title_color', 
	'default' => '',
	'label' => __('Site Title Color', 'angularity'),
	 'transport' => 'postMessage'
);

$colors[] = array(
	'slug'=>'text_color', 
	'default' => '',
	'label' => __('Text Color', 'angularity'),
	 'transport' => 'postMessage'
);

$colors[] = array(
	'slug'=>'accent_color', 
	'default' => '',
	'label' => __('Accent Color', 'angularity'),
	 'transport' => 'postMessage'
);

$colors[] = array(
	'slug'=>'entry_title_color', 
	'default' => '',
	'label' => __('Entry Title Color', 'angularity'),
	 'transport' => 'postMessage'
);

$colors[] = array(
	'slug'=>'links_color', 
	'default' => '',
	'label' => __('Links Color', 'angularity'),
	 'transport' => 'postMessage'
);

foreach( $colors as $color ) {
	// SETTINGS
	$wp_customize->add_setting(
		$color['slug'], array(
			'default' => $color['default'],
			'type' => 'option', 
			'capability' => 
			'edit_theme_options',
			 'transport' => 'postMessage'
		)
	);
	// CONTROLS
	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			$color['slug'], 
			array('label' => $color['label'], 
			'section' => 'colors',
			'settings' => $color['slug'])
		)
	);
}

// Add Logo

$wp_customize->add_setting( 'site_title_image' );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'site_title_image', array(
    'label'    => __( 'Site Title Image', 'angularity' ),
    'section'  => 'title_tagline',
    'priority'   => 2,
    'settings' => 'site_title_image',
) ) );





$wp_customize->add_setting('no_angles', array(
	'default'	=> '',
	
	));
$wp_customize->add_control('no_angles', array(
	'label'      => __('Angles', 'angularity'),
	'section'    => 'angles',
	'settings'   => 'no_angles',
	'type'       => 'radio',
	'priority'   => 7,
	'choices'    => array(
		'' => 'Clear',
		''   => 'Show Angles',
		'square-angles'   => 'Square Angles'
		
	),
));









$wp_customize->add_setting('site_title_weight', array(
	'default'	=> '',
	'transport' => 'postMessage',
	));
$wp_customize->add_control('site_title_weight', array(
	'label'      => __('Site Title Weight', 'angularity'),
	'section'    => 'title_tagline',
	'settings'   => 'site_title_weight',
	'type'       => 'radio',
	'priority'   => 7,
	'choices'    => array(
		'' => 'Clear',
		'100'   => '100',
		'200'   => '200',
		'300'   => '300',
		'400'   => '400',
		'600'   => '600',
		'500'   => '500',
		'700'   => '700',
		'800'   => '800',
		'900'   => '900'
	),
));




$wp_customize->add_setting('site_title_size', array(
	'default'	=> '',
	'transport' => 'postMessage',
	));
$wp_customize->add_control('site_title_size', array(
	'label'      => __('Site Title Size', 'angularity'),
	'section'    => 'title_tagline',
	'settings'   => 'site_title_size',
	'type'       => 'radio',
	'priority'   => 6,
	'choices'    => array(
		''   => 'Clear',
		'2.1rem'   => '21px',
		'2.4rem'   => '24px',
		'2.8rem'   => '28px',
		'3.2rem'   => '32px',
		'3.7rem'   => '37px',
		'4.2rem'   => '42px',
		'4.9rem'   => '49px',
		'5.6rem'   => '56px',
		'6.4rem'   => '64px'
	),
));










$wp_customize->add_setting('page_title_size', array(
	'default'	=> '',
	'transport' => 'postMessage',
	
	));
$wp_customize->add_control('page_title_size', array(
	'label'      => __('Page Title Size', 'angularity'),
	'section'    => 'fonts',
	'settings'   => 'page_title_size',
	'type'       => 'select',
	'priority'   => 5,
	'choices'    => array(
		''   => 'Clear',
		'2.1rem'   => '21px',
		'2.4rem'   => '24px',
		'2.8rem'   => '28px',
		'3.2rem'   => '32px',
		'3.7rem'   => '37px',
		'4.2rem'   => '42px',
		'4.9rem'   => '49px',
		'5.6rem'   => '56px',
		'6.4rem'   => '64px'
	),
));




$wp_customize->add_setting('page_title_weight', array(
	'default'	=> '',
	'transport' => 'postMessage',
	));
$wp_customize->add_control('page_title_weight', array(
	'label'      => __('Page Title Weight', 'angularity'),
	'section'    => 'fonts',
	'settings'   => 'page_title_weight',
	'type'       => 'select',
	'priority'   => 4,
	'choices'    => array(
		'' => 'Clear',
		'100'   => '100',
		'200'   => '200',
		'300'   => '300',
		'400'   => '400',
		'500'   => '500',
		'600'   => '600',
		'700'   => '700',
		'800'   => '800',
		'900'   => '900'
	),
));



$wp_customize->add_setting('body_font_size', array(
	'default'	=> '',
	'transport' => 'postMessage',
	));
$wp_customize->add_control('body_font_size', array(
	'label'      => __('Body Font Size', 'angularity'),
	'section'    => 'fonts',
	'settings'   => 'body_font_size',
	'type'       => 'select',
	'priority'   => 3,
	'choices'    => array(
		''   => 'Clear',
		'1.4rem'   => '14px',
		'1.6rem'   => '16px',
		'1.8rem'   => '18px',
		'2.1rem'   => '21px',
		'2.4rem'   => '24px'
	),
));





$wp_customize->add_setting('image_border', array(
	'default'	=> '',
	'transport' => 'postMessage',
	));
$wp_customize->add_control('image_border', array(
	'label'      => __('Image Border', 'angularity'),
	'section'    => 'image_options',
	'settings'   => 'image_border',
	'type'       => 'radio',
	'priority'   => 3,
	'choices'    => array(
		''   => 'Clear',
		'0px'    => '0px',
		'1px'    => '1px',
		'2px'    => '2px',
		'3px'    => '3px',
		'4px'    => '4px',
		'5px'    => '5px'
	),
));



$wp_customize->add_setting('rounded_image_corners', array(
	'default'	=> '',
	'transport' => 'postMessage',
	));
$wp_customize->add_control('rounded_image_corners', array(
	'label'      => __('Rounded Image Corners', 'angularity'),
	'section'    => 'image_options',
	'settings'   => 'rounded_image_corners',
	'type'       => 'radio',
	'priority'   => 3,
	'choices'    => array(
		''       => 'Clear',
		'0px'    => '0px',
		'5px'    => '5px',
		'10px'   => '10px',
		'20px'   => '20px',
		'30px'   => '30px',
		'40px'   => '40px',
		'50px'   => '50px',
		'80px'   => '80px',
		'120px'  => '120px'
	),
));





// Fonts


$wp_customize->add_setting('content_font', array(
	'default'	=> '',
	
	));
$wp_customize->add_control('content_font', array(
	'label'      => __('Content Font', 'angularity'),
	'section'    => 'fonts',
	'settings'   => 'content_font',
	'type'       => 'select',
	 'priority'   => 1,
	'choices'    => array(
		''   				=> 'Clear',
		'Lato'   			=> 'Lato',
		'Source Sans Pro'   => 'Source Sans Pro',
		'Open Sans'  		=> 'Open Sans',
		'Roboto'   			=> 'Roboto',
		'Exo 2'   			=> 'Exo 2',
		'Merriweather'   	=> 'Merriweather',
		'Merriweather Sans' => 'Merriweather Sans',
		'Lora'   			=> 'Lora',
		'Raleway'  			=> 'Raleway',
		'Josefin Slab'   	=> 'Josefin Slab',
		'Quicksand'   		=> 'Quicksand',
		'Sintony'   		=> 'Sintony',
		'Noto Sans'   		=> 'Noto Sans',
		'Droid Sans'   		=> 'Droid Sans',
		'Droid Serif'   	=> 'Droid Serif',
		'PT Sans'   		=> 'PT Sans',
		'Roboto Slab'  		=> 'Roboto Slab',
		'Rokkitt'  			=> 'Rokkitt',
		'Cabin'  			=> 'Cabin',
		'Arvo'  			=> 'Arvo',
		'Oldenburg'  		=> 'Oldenburg',
		'Cutive Mono'  		=> 'Cutive Mono',
		'Sanchez'  			=> 'Sanchez',
		'Alegreya'   		=> 'Alegreya',
		'Alegreya Sans'   	=> 'Alegreya Sans',
		'Lustria'   		=> 'Lustria',
		'Arbutus Slab'   	=> 'Arbutus Slab',
		'Aleo'   			=> 'Aleo',
		'Linux Biolinum'   	=> 'Linux Biolinum',
		'Poly'   			=> 'Poly'


		
	),
));





$wp_customize->add_setting('page_title_font', array(
	'default'	=> '',
	
	));
$wp_customize->add_control('page_title_font', array(
	'label'      => __('Page Title Font', 'angularity'),
	'section'    => 'fonts',
	'settings'   => 'page_title_font',
	'type'       => 'select',
	 'priority'   => 2,
	'choices'    => array(
		''   					=> 'Clear',
		'Lato'   				=> 'Lato',
		'Source Sans Pro'   	=> 'Source Sans Pro',
		'Open Sans'   			=> 'Open Sans',
		'Roboto'   				=> 'Roboto',
		'Exo 2'   				=> 'Exo 2',
		'Merriweather'   		=> 'Merriweather',
		'Merriweather Sans' 	=> 'Merriweather Sans',
		'Lora'   				=> 'Lora',
		'Raleway'  				=> 'Raleway',
		'Josefin Slab'   		=> 'Josefin Slab',
		'Quicksand'   			=> 'Quicksand',
		'Sintony'   			=> 'Sintony',
		'Noto Sans'   			=> 'Noto Sans',
		'Droid Sans'   			=> 'Droid Sans',
		'Droid Serif'   		=> 'Droid Serif',
		'PT Sans'   			=> 'PT Sans',
		'Roboto Slab'  			=> 'Roboto Slab',
		'Rokkitt'  				=> 'Rokkitt',
		'Cabin'  				=> 'Cabin',
		'Arvo'  				=> 'Arvo',
		'Oldenburg'  			=> 'Oldenburg',
		'Cutive Mono'  			=> 'Cutive Mono',
		'Sanchez'  				=> 'Sanchez',
		'Alegreya'   			=> 'Alegreya',
		'Alegreya Sans'   		=> 'Alegreya Sans',
		'Lustria'   			=> 'Lustria',
		'Arbutus Slab'   		=> 'Arbutus Slab',
		'Aleo'   				=> 'Aleo',
		'Linux Biolinum'   		=> 'Linux Biolinum',
		'Poly'   				=> 'Poly',
		'Happy Monkey'   		=> 'Happy Monkey',
		'Prosto One'   			=> 'Prosto One',
		'McLaren'				=> 'McLaren',
		'Cherry Cream Soda'		=> 'Cherry Cream Soda',
		'Pompiere'				=> 'Pompiere',
		'Stint Ultra Expanded'	=> 'Stint Ultra Expanded',
		'Overlock'				=> 'Overlock',
		'Comfortaa'				=> 'Comfortaa',
		'Architects Daughter'	=> 'Architects Daughter',
		'Covered By Your Grace'	=> 'Covered By Your Grace',
		'Dancing Script'		=> 'Dancing Script',
		'IM Fell Great Primer'	=> 'IM Fell Great Primer',
		'Oxygen'				=> 'Oxygen'

		
	),
));




}
add_action( 'customize_register', 'angularity_customize_register' );

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function angularity_customize_preview_js() {
	wp_enqueue_script( 'angularity_customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20130508', true );
}
add_action( 'customize_preview_init', 'angularity_customize_preview_js' );

function customizer_header_code() {


// Colors
$text_color 			= get_option('text_color');
$entry_title_color 		= get_option('entry_title_color');
$site_title_color 		= get_option('site_title_color');
$accent_color 			= get_option('accent_color');
$entry_title_color 		= get_option('entry_title_color');
$links_color 			= get_option('links_color');

// Header Options
$site_title_image 		= get_theme_mod('site_title_image');

//Fonts
$page_title_size 		= get_theme_mod('page_title_size');
$site_title_size 		= get_theme_mod('site_title_size');
$site_title_weight 		= get_theme_mod('site_title_weight');
$page_title_weight 		= get_theme_mod('page_title_weight');
$body_font_size 		= get_theme_mod('body_font_size');
$content_font 			= get_theme_mod('content_font');
$page_title_font 		= get_theme_mod('page_title_font');

// Image Options
$image_border 			= get_theme_mod('image_border');
$rounded_image_corners 	= get_theme_mod('rounded_image_corners');

//Angularity
$no_angles 		= get_theme_mod('no_angles');

// load content fonts 

if (empty($content_font)):
echo "<link href='http://fonts.googleapis.com/css?family=Source+Sans+Pro:400,300,400italic,600,700,900,600italic,200,200italic' rel='stylesheet' type='text/css'>";
$content_font = 'Source Sans Pro';



elseif ($content_font == 'Raleway'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Raleway:400,100,200,300,500,600,700,800,900' rel='stylesheet' type='text/css'>";
elseif ($content_font == 'Roboto Slab'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Roboto+Slab:400,100,300,700' rel='stylesheet' type='text/css'>";
elseif ($content_font == 'Merriweather'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Merriweather:400,300,300italic,400italic,700,900' rel='stylesheet' type='text/css'>";
elseif ($content_font == 'Merriweather Sans'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Merriweather+Sans:400,300,300italic,400italic,700,800' rel='stylesheet' type='text/css'>";
elseif ($content_font == 'Aleo'): 
	echo '<link rel="stylesheet" href="';
	echo get_stylesheet_directory_uri();
	echo '/fonts/Aleoweb/stylesheet.css" type="text/css" charset="utf-8" />';
elseif ($content_font == 'Linux Biolinum'): 
	echo '<link rel="stylesheet" href="';
	echo get_stylesheet_directory_uri();
	echo '/fonts/Linux_Biolinum_web/stylesheet.css" type="text/css" charset="utf-8" />';
elseif ($content_font == 'Alegreya Sans'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Alegreya+Sans:400,100,300,400italic,500,700,800,900,700italic,500italic' rel='stylesheet' type='text/css'>";
elseif ($content_font == 'Alegreya'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Alegreya:400,400italic,700,700italic' rel='stylesheet' type='text/css'>";
elseif ($content_font == 'Arbutus Slab'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Arbutus+Slab' rel='stylesheet' type='text/css'>";
elseif ($content_font == 'Poly'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Poly:400,400italic' rel='stylesheet' type='text/css'>";
elseif ($content_font == 'Sanchez'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Sanchez:400,400italic' rel='stylesheet' type='text/css'>";
elseif ($content_font == 'Lustria'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Lustria' rel='stylesheet' type='text/css'>";
elseif ($content_font == 'Josefin Slab'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Josefin+Slab:400,100,300,400italic,600,600italic,700,700italic' rel='stylesheet' type='text/css'>";
elseif ($content_font == 'Cutive Mono'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Cutive+Mono' rel='stylesheet' type='text/css'>";
elseif ($content_font == 'Arvo'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Arvo:400,400italic,700,700italic' rel='stylesheet' type='text/css'>";
elseif ($content_font == 'Sintony'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Sintony:400,700' rel='stylesheet' type='text/css'>";
elseif ($content_font == 'Noto Sans'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Noto+Sans:400,400italic,700,700italic' rel='stylesheet' type='text/css'>";
elseif ($content_font == 'PT Sans'): 
	echo "<link href='http://fonts.googleapis.com/css?family=PT+Sans:400,700' rel='stylesheet' type='text/css'>";
elseif ($content_font == 'Quicksand'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Quicksand:400,700' rel='stylesheet' type='text/css'>";
elseif ($content_font == 'Cabin'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Cabin:400,700' rel='stylesheet' type='text/css'>";
elseif ($content_font == 'Droid Sans'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Droid+Sans:400,700' rel='stylesheet' type='text/css'>";
elseif ($content_font == 'Droid Serif'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Droid+Serif:400,700' rel='stylesheet' type='text/css'>";
elseif ($content_font == 'Lato'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Lato:400,100,300,400italic,700,900' rel='stylesheet' type='text/css'>";
elseif ($content_font == 'Lora'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Lora:400,400italic,700,700italic' rel='stylesheet' type='text/css'>";
elseif ($content_font == 'Open Sans'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Open+Sans:400,300,300italic,400italic,600,700,800' rel='stylesheet' type='text/css'>";
elseif ($content_font == 'Source Sans Pro'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Source+Sans+Pro:400,300,400italic,600,700,900,600italic,200,200italic' rel='stylesheet' type='text/css'>";
elseif ($content_font == 'Roboto'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Roboto:400,300,300italic,400italic,700,900,100,100italic,500' rel='stylesheet' type='text/css'>";
elseif ($content_font == 'Exo 2'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Exo+2:400,100,200,300,300italic,400italic,600,700,800,900' rel='stylesheet' type='text/css'>";
elseif ($content_font == 'Rokkitt'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Rokkitt:400,700' rel='stylesheet' type='text/css'>";
elseif ($content_font == ''): 
	echo "";
endif	;





echo "
";
if ($page_title_font == 'Raleway'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Raleway:400,600' rel='stylesheet' type='text/css'>";
elseif ($page_title_font == 'Roboto Slab'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Roboto+Slab:400,700' rel='stylesheet' type='text/css'>";
elseif ($page_title_font == 'Merriweather'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Merriweather:400,400italic,700,900' rel='stylesheet' type='text/css'>";
elseif ($page_title_font == 'Merriweather Sans'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Merriweather+Sans:400,400italic,700,800' rel='stylesheet' type='text/css'>";
 elseif ($page_title_font == 'Aleo'): 
	echo '<link rel="stylesheet" href="';
	echo get_stylesheet_directory_uri();
	echo '/fonts/Aleoweb/stylesheet.css" type="text/css" charset="utf-8" />';
 elseif ($page_title_font == 'Linux Biolinum'): 
	echo '<link rel="stylesheet" href="';
	echo get_stylesheet_directory_uri();
	echo '/fonts/Linux_Biolinum_web/stylesheet.css" type="text/css" charset="utf-8" />';
elseif ($page_title_font == 'Alegreya'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Alegreya:400,400italic,700,700italic' rel='stylesheet' type='text/css'>";
elseif ($page_title_font == 'Arbutus Slab'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Arbutus+Slab' rel='stylesheet' type='text/css'>";
elseif ($page_title_font == 'Poly'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Poly:400,400italic' rel='stylesheet' type='text/css'>";
elseif ($page_title_font == 'Sanchez'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Sanchez:400,400italic' rel='stylesheet' type='text/css'>";
elseif ($page_title_font == 'Lustria'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Lustria' rel='stylesheet' type='text/css'>";
elseif ($page_title_font == 'Josefin Slab'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Josefin+Slab:400,400italic,700,700italic' rel='stylesheet' type='text/css'>";
elseif ($page_title_font == 'Cutive Mono'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Cutive+Mono' rel='stylesheet' type='text/css'>";
elseif ($page_title_font == 'Arvo'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Arvo:400,400italic,700,700italic' rel='stylesheet' type='text/css'>";
elseif ($page_title_font == 'Sintony'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Sintony:400,700' rel='stylesheet' type='text/css'>";
elseif ($page_title_font == 'Noto Sans'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Noto+Sans:400,400italic,700,700italic' rel='stylesheet' type='text/css'>";
elseif ($page_title_font == 'PT Sans'): 
	echo "<link href='http://fonts.googleapis.com/css?family=PT+Sans:400,700' rel='stylesheet' type='text/css'>";
elseif ($page_title_font == 'Quicksand'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Quicksand:400,700' rel='stylesheet' type='text/css'>";
elseif ($page_title_font == 'Cabin'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Cabin:400,700' rel='stylesheet' type='text/css'>";
elseif ($page_title_font == 'Droid Sans'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Droid+Sans:400,700' rel='stylesheet' type='text/css'>";
elseif ($page_title_font == 'Droid Serif'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Droid+Serif:400,700' rel='stylesheet' type='text/css'>";
elseif ($page_title_font == 'Lato'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Lato:400,400italic,700,900' rel='stylesheet' type='text/css'>";
elseif ($page_title_font == 'Lora'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Lora:400,400italic,700,700italic' rel='stylesheet' type='text/css'>";
elseif ($page_title_font == 'Open Sans'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Open+Sans:400,400italic,700,800,600' rel='stylesheet' type='text/css'>";
elseif ($page_title_font == 'Source Sans Pro'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Source+Sans+Pro:200,300,400,400italic,600,700,900,600' rel='stylesheet' type='text/css'>";
elseif ($page_title_font == 'Roboto'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Roboto:400,400italic,700,900' rel='stylesheet' type='text/css'>";
elseif ($page_title_font == 'Montserrat'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Montserrat:400,700' rel='stylesheet' type='text/css'>";
elseif ($page_title_font == 'Rokkitt'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Rokkitt:400,700' rel='stylesheet' type='text/css'>";
elseif ($page_title_font == 'Happy Monkey'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Happy+Monkey' rel='stylesheet' type='text/css'>";
elseif ($page_title_font == 'Prosto One'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Prosto+One' rel='stylesheet' type='text/css'>";
elseif ($page_title_font == 'McLaren'): 
	echo "<link href='http://fonts.googleapis.com/css?family=McLaren' rel='stylesheet' type='text/css'>";
elseif ($page_title_font == 'Cherry Cream Soda'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Cherry+Cream+Soda' rel='stylesheet' type='text/css'>";
elseif ($page_title_font == 'Pompiere'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Pompiere' rel='stylesheet' type='text/css'>";
elseif ($page_title_font == 'Stint Ultra Expanded'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Stint+Ultra+Expanded' rel='stylesheet' type='text/css'>";
elseif ($page_title_font == 'Overlock'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Overlock:400,700,900,400italic,700italic,900italic' rel='stylesheet' type='text/css'>";
elseif ($page_title_font == 'Comfortaa'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Comfortaa:400,300,700' rel='stylesheet' type='text/css'>";
elseif ($page_title_font == 'Architects Daughter'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Architects+Daughter' rel='stylesheet' type='text/css'>";
elseif ($page_title_font == 'Covered By Your Grace'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Covered+By+Your+Grace' rel='stylesheet' type='text/css'>";
elseif ($page_title_font == 'Dancing Script'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Dancing+Script:400,700' rel='stylesheet' type='text/css'>";
elseif ($page_title_font == 'IM Fell Great Primer'): 
	echo "<link href='http://fonts.googleapis.com/css?family=IM+Fell+Great+Primer:400,400italic' rel='stylesheet' type='text/css'>";
elseif ($page_title_font == 'Oxygen'): 
	echo "<link href='http://fonts.googleapis.com/css?family=Oxygen:400,300,700' rel='stylesheet' type='text/css'>";
elseif ($page_title_font == ''): 
	echo "<!-- No page title font -->";
endif	;








echo '
<style  type="text/css">
';

if (!empty($links_color)):
	echo '	a, a:visited { color:',$links_color,' ;  }
 ';
endif;

if (!empty($text_color)): 
	echo '	body, button, input, select, textarea, .entry-title, .entry-title a, .entry-title a:link, .entry-title a:visited, .widget ul a, .widget ul a:visited, .socialbuttons a, .socialbuttons a:visited, .page-title, .entry-meta a { color:',$text_color,' ; }
'; endif;


if (!empty($site_title_color)):
	echo '	.site-title a { color:',$site_title_color,' ;  }
 ';
 endif;


if (!empty($accent_color)):
	echo '	.full-page-nav-bar, .widgetangle, .postangle, .main-navigation ul ul a:hover { background-color:',$accent_color,' ;  }
  ';
endif;

if (!empty($content_font)): 
	echo '	body, button, input, select, textarea, .entry-title, .entry-title a, .entry-title a:visited, .site-description,.main-navigation,  .page-title {font-family:"', $content_font, '", sans-serif; }
'; endif;


if (!empty($page_title_font)): 
	echo '	.entry-title, .entry-title a, .entry-title a:visited { font-family:"', $page_title_font, '", serif ; }
'; endif;

if (!empty($body_font_size)): 
	echo '	body, button, input, select, textarea, .page-title { font-size:', $body_font_size, '; }
'; endif;


if (!empty($entry_title_color)):
	echo '.entry-title,	.entry-title a, .entry-title a:link, .entry-title a:visited { color:',$entry_title_color,' ; }
 '; 
  	echo '	#back-top a { color:',$entry_title_color,' ;  }
 ';
 endif;



if (!empty($page_title_size)):  
	echo '	.entry-title, entry-title a, .entry-title a:visited {  font-size:', $page_title_size,'; }
'; endif;

if (!empty($page_title_weight)): 
	echo '	.entry-title, entry-title a, .entry-title a:visited {  font-weight: ', $page_title_weight,'; }
'; endif;

if (!empty($site_title_weight)): 
	echo '	.site-title a {  font-weight:', $site_title_weight,'; }
'; endif;


if (!empty($site_title_size)): 
	echo '	.site-title a {  font-size:', $site_title_size,'; }
'; endif;


if (!empty($image_border)):
	echo '	.entry-content img { border-width:',$image_border,' ;  }
 ';
endif;


if (!empty($rounded_image_corners)):
echo '	.entry-content img { -webkit-border-radius:',$rounded_image_corners,' ;border-radius:', $rounded_image_corners,' ;  }
  ';
 endif;


if ($no_angles =='square-angles'):
	echo '	.menu-decoration:before, .widgetangle, .postangle {
	-moz-transform: scale(1) rotate(0deg) translateX(0px) skewX(0deg) skewY(0deg);
	-webkit-transform: scale(1) rotate(0deg) translateX(0px) skewX(0deg) skewY(0deg);
	-o-transform: scale(1) rotate(0deg) translateX(0px) skewX(0deg) skewY(0deg);
	-ms-transform: scale(1) rotate(0deg) translateX(0px) skewX(0deg) skewY(0deg);
	transform: scale(1) rotate(0deg) translateX(0px) skewX(0deg) skewY(0deg);	
}
  ';
  echo '.widget-area .widget {	padding-bottom: 16px;}.menu-decoration:before {left:0;width:100%;}';
 endif;















echo '</style>';



}

add_action('customizations', 'customizer_header_code');